@@ -1,6 +1,6 @@
 package Test::Trap::Builder;
 
-use version; $VERSION = qv('0.3.3');
+use version; $VERSION = qv('0.3.4');
 
 use strict;
 use warnings;
@@ -165,7 +165,11 @@ BEGIN { # Test callback registration and test method generation:
     my $ok;
     local $trap->Prop->{test_accessor} = "$accessor->{name}($index)";
     local $Test::Builder::Level = $Test::Builder::Level+1;
-    local($!, $^E) = ($!, $^E);
+
+    # Work around perl5 bug #119683, as per Test-Trap bug #127112:
+    my @copy = ($!, $^E);
+    local ($!, $^E) = @copy;
+
     $ok = $test->{code}->(@targs) or $trap->TestFailure;
     $ok;
   };
@@ -381,7 +385,7 @@ Test::Trap::Builder - Backend for building test traps
 
 =head1 VERSION
 
-Version 0.3.3
+Version 0.3.4
 
 =head1 SYNOPSIS
 
